summary refs log tree commit diff
path: root/synapse/config
diff options
context:
space:
mode:
authorPatrick Cloke <clokep@users.noreply.github.com>2022-02-17 08:32:18 -0500
committerGitHub <noreply@github.com>2022-02-17 13:32:18 +0000
commite69f8f0a8e3b3f3b647efc42fe67b6b9270d26e0 (patch)
tree38e4e9022feb5393fd614291504bb0da6c65780c /synapse/config
parent`send_join` response: get create event from `state`, not `auth_chain` (#12005) (diff)
downloadsynapse-e69f8f0a8e3b3f3b647efc42fe67b6b9270d26e0.tar.xz
Remove support for the legacy structured logging configuration. (#12008)
Diffstat (limited to 'synapse/config')
-rw-r--r--synapse/config/logger.py12
1 files changed, 8 insertions, 4 deletions
diff --git a/synapse/config/logger.py b/synapse/config/logger.py
index b7145a44ae..cbbe221965 100644
--- a/synapse/config/logger.py
+++ b/synapse/config/logger.py
@@ -33,7 +33,6 @@ from twisted.logger import (
     globalLogBeginner,
 )
 
-from synapse.logging._structured import setup_structured_logging
 from synapse.logging.context import LoggingContextFilter
 from synapse.logging.filter import MetadataFilter
 
@@ -138,6 +137,12 @@ Support for the log_file configuration option and --log-file command-line option
 removed in Synapse 1.3.0. You should instead set up a separate log configuration file.
 """
 
+STRUCTURED_ERROR = """\
+Support for the structured configuration option was removed in Synapse 1.54.0.
+You should instead use the standard logging configuration. See
+https://matrix-org.github.io/synapse/v1.54/structured_logging.html
+"""
+
 
 class LoggingConfig(Config):
     section = "logging"
@@ -292,10 +297,9 @@ def _load_logging_config(log_config_path: str) -> None:
     if not log_config:
         logging.warning("Loaded a blank logging config?")
 
     # If the old structured logging configuration is being used, convert it to
     # the new style configuration.
     if "structured" in log_config and log_config.get("structured"):
-        log_config = setup_structured_logging(log_config)
+        raise ConfigError(STRUCTURED_ERROR)
 
     logging.config.dictConfig(log_config)
@@ -292,10 +297,9 @@ def _load_logging_config(log_config_path: str) -> None:
         logging.warning("Loaded a blank logging config?")
 
-    # If the old structured logging configuration is being used, convert it to
-    # the new style configuration.
+    # If the old structured logging configuration is being used, raise an error.
     if "structured" in log_config and log_config.get("structured"):